import {
  csv,
  select,
  pie,
  arc,
  scaleOrdinal,
  schemeCategory10,
} from 'd3';

export const pieChart = (data, container) => {
  const width = 960; // Fixed width
  const height = 500; // Fixed height
  const radius = Math.min(width, height) / 2; // Radius of the pie chart

  const svg = select(container)
    .append('svg')
    .attr('width', width)
    .attr('height', height)
    .append('g')
    .attr(
      'transform',
      `translate(${width / 2}, ${height / 2})`,
    ); // Centering the pie chart

  // Count the occurrences of each occupation
  const occupationCounts = data.reduce((acc, d) => {
    acc[d.Occupation] = (acc[d.Occupation] || 0) + 1;
    return acc;
  }, {});

  // Create the pie chart
  const pieGenerator = pie()
    .sort(null) // Do not sort the slices
    .value((d) => d[1]);

  const arcGenerator = arc()
    .innerRadius(0)
    .outerRadius(radius - 10); // Slightly smaller than the radius

  const color = scaleOrdinal(schemeCategory10);

  const slices = svg
    .selectAll('.slice')
    .data(pieGenerator(Object.entries(occupationCounts)))
    .enter()
    .append('path')
    .attr('class', 'slice')
    .attr('d', arcGenerator)
    .attr('fill', (d, i) => color(i));

  // Add the legend
  const legend = svg
    .selectAll('.legend')
    .data(Object.keys(occupationCounts))
    .enter()
    .append('g')
    .attr('class', 'legend')
    .attr(
      'transform',
      (d, i) =>
        `translate(${-(width / 2 - 20)}, ${-(height / 2 - 30) + i * 20})`,
    );

  legend
    .append('rect')
    .attr('width', 18)
    .attr('height', 18)
    .style('fill', (d, i) => color(i));

  legend
    .append('text')
    .attr('x', 24)
    .attr('y', 9)
    .attr('dy', '.35em')
    .text((d) => `${d}: ${occupationCounts[d]}`);

  // Add chart title
  svg
    .append('text')
    .attr('x', 0)
    .attr('y', -radius - 20)
    .attr('text-anchor', 'middle')
    .style('font-size', '20px')
    .text('Occupation Distribution');
};
